{
  lib,
  ...
}:
{
  deployment = {
    targetHost = "son.kat";
    tags = [ "kat-vms" ];
  };

  imports = [
    ./hardware-configuration.nix
    ./disks.nix
  ];

  boot = {
    loader = {
      systemd-boot.enable = true;
      efi.canTouchEfiVariables = true;
    };
    kernelParams = [ "console=ttyS0" ];
  };

  kat = {
    proxies = {
      ip = "192.168.122.5";
      aliases = [
        "cof.katvayor.net"
      ];
    };
  };

  systemd.network.enable = lib.mkForce false;
  networking = {
    useNetworkd = lib.mkForce false;
    interfaces."enp1s0" = {
      useDHCP = false;
      ipv4.addresses = [
        {
          address = "192.168.122.5";
          prefixLength = 24;
        }
      ];
      ipv6.addresses = [
        {
          address = "fe80::5";
          prefixLength = 64;
        }
      ];
    };
    defaultGateway = "192.168.122.1";
    defaultGateway6 = {
      address = "fe80::1";
      interface = "enp1s0";
    };
    nameservers = [
      "192.168.122.1"
      "fe80::1%enp1s0"
    ];
  };

  networking.firewall.enable = false;

  security.acme = {
    acceptTerms = true;
    defaults.email = "root@katvayor.net";
  };
  services = {
    openssh.enable = true;
    qemuGuest.enable = true;
    getty.autologinUser = "root";
    nginx = {
      enable = true;
      virtualHosts = {
        "son.katvayor.net" = {
          enableACME = true;
          addSSL = true;
        };
        "cof.katvayor.net" = {
          enableACME = true;
          addSSL = true;
          locations."/" = {
            proxyPass = "http://localhost:8000/";
            recommendedProxySettings = true;
          };
        };
      };
    };
  };

  system.stateVersion = "23.11";
}
