{
  pkgs,
  lib,
  mods,
  ...
}:
{
  imports = with mods.global; [ sway ];

  users.users.catvayor = {
    isNormalUser = true;
    extraGroups = [
      "wheel"
      "usb"
      "networkmanager"
      "video"
      "audio"
      "libvirtd"
    ];
    packages = with pkgs; [
      tree
      nixfmt-rfc-style
      ghq
    ];
  };

  services.gvfs.enable = true;
  programs.thunar = {
    enable = true;
    plugins = with pkgs.xfce; [
      thunar-volman
      thunar-archive-plugin
      thunar-media-tags-plugin
    ];
  };

  home-manager.users.catvayor = {
    imports = with mods.home; [
      sway
      ssh
      mail
    ];

    programs = {
      alacritty = {
        enable = true;
        settings = lib.importTOML ./cat-alacritty.toml;
      };
      thunderbird = {
        enable = true;
        profiles = { };
      };
      git = {
        enable = true;
        userName = "catvayor";
        userEmail = "catvayor@katvayor.net";
        signing = {
          key = null;
          signByDefault = true;
        };
      };
    };

    home = {
      packages = with pkgs; [
        wl-clipboard
        firefox
        pwvucontrol
        libnotify
        zathura
        vlc
        prismlauncher

        discord
        signal-desktop
        keepassxc
        ferdium
      ];
      pointerCursor = {
        package = pkgs.breeze-hacked-cursor-theme;
        name = "Breeze_Hacked";
      };
    };

    services.mako = {
      enable = true;
      width = 400;
      height = 200;
      maxVisible = 5;
      backgroundColor = "#8C3586";
      textColor = "#F4F40E";
      borderColor = "#F4F40E";
      defaultTimeout = 5000;
    };

    gtk = {
      enable = true;
      theme = {
        package = pkgs.arc-theme.overrideAttrs (o: {
          postInstall =
            (o.postInstall or "")
            + ''
              pushd $out/share/themes/Arc-Dark/gtk-4.0/
              . <(gresource list gtk.gresource |\
                  sed 's/^\(.*\/arc-theme\/\)\(.*\)$/mkdir -p $(dirname ".\/\2");\
                      gresource extract gtk.gresource \"\1\2\" > \2/')
              substituteInPlace gtk.css\
                  --replace-fail 'resource:///org/gnome/arc-theme' "file://$(realpath .)"
              popd
            '';
        });
        name = "Arc-Dark";
      };
      iconTheme = {
        package = pkgs.arc-icon-theme;
        name = "Arc";
      };
      cursorTheme = {
        package = pkgs.breeze-hacked-cursor-theme;
        name = "Breeze_Hacked";
      };
    };
    xdg.enable = true;
  };
}
